package
Version:
v0.0.0-...-ce1c9ab
Opens a new window with list of versions in this module.
Published: Mar 31, 2023
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type WaitGroup struct {
}
WaitGroup 一个异步结构体
NewPool 生成一个工作池,coreNum限制
Source Files
¶
Click to show internal directories.
Click to hide internal directories.